@@ -10,7 +10,7 @@ sub output;
 sub run {
 
 $ENV{PGPLOT_XW_WIDTH}=0.3;
-$ENV{PGPLOT_DEV}=$^O =~ /MSWin32/ ? '/GW' : "/XSERVE";
+$ENV{PGPLOT_DEV}="/XSERVE";
 
 comment q|
     Welcome to this tour of the PDL's PGPLOT interface.
@@ -20,9 +20,9 @@ comment q|
     not designed to give a full tour of PGPLOT, you are advised to see
     the routines provided with pgperl for that.
 
-    The PDL::Graphics::PGPLOT module provides a high-level interface
-    to PGPLOT. However if you want even better control of your plots 
-    you might want to include the PGPLOT module specifically:
+    The PGPLOT module is included by default when you use PDL. However
+    if you want even better control of your plots you might want to
+    include the PGPLOT module specifically:
 
        use PGPLOT;
 
@@ -36,12 +36,10 @@ comment q|
 |;
 
 act q|
-    # ensure the module is loaded (required for PDL versions >= 2.004)
-    use PDL::Graphics::PGPLOT;
     # The size of the window can be specified
     $ENV{PGPLOT_XW_WIDTH}=0.3;
     # You can set your device explicitly
-    $id=dev($^O =~ /MSWin32/ ? '/GW' : '/XSERVE');
+    dev('/XSERVE');
 |;
 
 act q|
@@ -83,7 +81,7 @@ act q|
 |;
 
 act q|
-    # 2D data can also easily be accommodated:
+    # 2D data can also easily be accomodated:
 
     # First make a simple image
     $gradient=sequence(40,40);
@@ -214,8 +212,7 @@ act q|
   $c =  zeroes(300)->xlinvals(0,12)+i*zeroes(300)->xlinvals(2,10);
   $sin = sin $c;
   line $sin->im, $sin->re;   # look at the result in the complex plane
-  #close the window--we're done!
-  close_window($id); 
+  
 |;
 
 }
