@@ -9,7 +9,6 @@ use Config;
 use PDL::Core;
 use PDL::Exporter;
 use DynaLoader;
-use Carp;
 @ISA    = qw( PDL::Exporter DynaLoader );
 
 bootstrap PDL::CallExt;
@@ -27,16 +26,15 @@ PDL::CallExt - call functions in external shared libraries
 
 =head1 DESCRIPTION
 
-callext() loads in a shareable object (i.e. compiled code) using
-Perl's dynamic loader, calls the named function and passes a list of
-piddle arguments to it.
+callext() loads in a shareable object (i.e. compiled code) using Perl's
+dynamic loader, calls the named function and passes a list of piddle arguments
+to it.
 
-It provides a reasonably portable way of doing this, including
-compiling the code with the right flags, though it requires simple
-perl and C wrapper routines to be written. You may prefer to use PP,
-which is much more portable. See L<PDL::PP>. You should definitely use
-the latter for a 'proper' PDL module, or if you run in to the
-limitations of this module.
+It provides a reasonably portable way of doing this, including compiling the
+code with the right flags, though it requires simple perl and C wrapper
+routines to be written. You may prefer to use PP, which is much more
+portable. See L<PDL::PP>. You should definitely use the latter for a 'proper'
+PDL module, or if you run in to the limitations of this module.
 
 =head1 API
 
@@ -71,11 +69,11 @@ pdlsimple.h defines a simple N-dimensional data structure which looks like this:
 
 (PDL_Long is always a 4 byte int and is defined in pdlsimple.h)
 
-This is a simplification of the internal representation of piddles in PDL which is
+This is a simplification of the internal reprensation of piddles in PDL which is
 more complicated because of threading, dataflow, etc. It will usually be found
 somewhere like /usr/local/lib/perl5/site_perl/PDL/pdlsimple.h
 
-Thus to actually use this to call real functions one would need to write a wrapper.
+Thus to actually use this to call real functions one would need to right a wrapper.
 e.g. to call a 2D image processing routine:
 
  void myimage_processer(double* image, int nx, int ny);
@@ -149,9 +147,9 @@ sub callext{
     my($file,$symbol, @pdl_args) = @_;
 
     my $libref = DynaLoader::dl_load_file($file);
-    my $err    = DynaLoader::dl_error(); barf $err if !defined $libref;
+    my $err    = DynaLoader::dl_error(); barf $err if defined $err;
     my $symref = DynaLoader::dl_find_symbol($libref, $symbol);
-    $err       = DynaLoader::dl_error(); barf $err if !defined $symref;
+    $err       = DynaLoader::dl_error(); barf $err if defined $err;
 
     _callext_int($symref, @pdl_args);
 1;}
@@ -180,49 +178,17 @@ sub callext_cc {
 	my @args = @_>0 ? @_ : @ARGV;
 	my ($src, $ccflags, $ldflags, $output) = @args;
 	my $cc_obj;
-	($cc_obj = $src) =~ s/\.c$/$Config{_o}/;
+	($cc_obj = $src) =~ s/\.c$/.o/;
 	my $ld_obj = $output;
-	($ld_obj = $cc_obj) =~ s/\.o$/\.$Config{dlext}/ unless defined $output;
-
-	# Output flags for compiler depend on os.
-	# -o on cc and gcc, or /Fo" " on MS Visual Studio
-	# Need a start and end string
-	my $do = ( $Config{cc} eq 'cl' ? '/Fo"' : '-o ');
-	my $eo = ( $^O =~ /MSWin/i ? '"' : '' );
-
-	# Compiler command
-        # Placing $ccflags *before* installsitelib/PDL/Core enables us to include
-        # the appropriate 'pdlsimple.h' during 'make test'.
+	($ld_obj = $cc_obj) =~ s/\.o$/.$Config{dlext}/ unless defined $output;
 	my $cc_cmd = join(' ', map { $Config{$_} } qw(cc ccflags cccdlflags)) .
-		qq{ $ccflags "-I$Config{installsitelib}/PDL/Core" -c $src $do$cc_obj$eo};
-
-	# The linker output flag is -o on cc and gcc, and -out: on MS Visual Studio
-	my $o = ( $Config{cc} eq 'cl' ? '-out:' : '-o ');
-
-	# Setup the LD command. Do not want the env var on Windows
-	my $ld_cmd = ( $^O =~ /MSWin|android/i ? ' ' : 'LD_RUN_PATH="" ');
-
-	my $libs = $^O =~ /MSWin/i ?
-                 $Config{libs} :
-                 ''; # used to be $Config{libs} but that bombs
-	               # on recent debian platforms
-	$ld_cmd .=
+		" -I$Config{installsitelib}/PDL/Core $ccflags -c $src -o $cc_obj";
+	my $ld_cmd = 'LD_RUN_PATH="" '.
 		join(' ', map { $Config{$_} } qw(ld lddlflags)) .
-		" $libs $ldflags $o$ld_obj $cc_obj";
+		" $ldflags -o $ld_obj $cc_obj";
 	my $cmd = "$cc_cmd; $ld_cmd";
 	print $cmd,"\n";
-
-	# Run the command in two steps so that we can check status
-	# of each and also so that we dont have to rely on ';' command
-	# separator
-
-	system $cc_cmd and croak " compiling $src";
-
-      # Fix up ActiveState-built perl. Is this a reliable fix ?
-      $ld_cmd =~ s/\-nodefaultlib//g if $Config{cc} eq 'cl';
-
-	system $ld_cmd and croak "Error linking $cc_obj";
-	return 1;
+	system $cmd;
 }
 
 =head1 AUTHORS
